@@ -23,6 +23,7 @@ from datamodel_code_generator import (
     DEFAULT_BASE_CLASS,
     Error,
     InputFileType,
+    InvalidClassNameError,
     enable_debug_message,
     generate,
 )
@@ -106,6 +107,17 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--use-standard-collections',
+    help='Use standard collections for type hinting (list, dict)',
+    action='store_true',
+    default=None,
+)
+
+arg_parser.add_argument(
+    '--class-name', help='Set class name of root model', default=None,
+)
+
 arg_parser.add_argument(
     '--custom-template-dir', help='Custom template directory', type=str
 )
@@ -164,6 +176,8 @@ class Config(BaseModel):
     allow_population_by_field_name: bool = False
     use_default: bool = False
     force_optional: bool = False
+    class_name: Optional[str] = None
+    use_standard_collections: bool = False
 
     def merge_args(self, args: Namespace) -> None:
         for field_name in self.__fields__:
@@ -258,8 +272,13 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             allow_population_by_field_name=config.allow_population_by_field_name,
             apply_default_values_for_required_fields=config.use_default,
             force_optional_for_required_fields=config.force_optional,
+            class_name=config.class_name,
+            use_standard_collections=config.use_standard_collections,
         )
         return Exit.OK
+    except InvalidClassNameError as e:
+        print(f'{e} You have to set --class-name option', file=sys.stderr)
+        return Exit.ERROR
     except Error as e:
         print(str(e), file=sys.stderr)
         return Exit.ERROR
