@@ -3,8 +3,6 @@ from typing import Any, DefaultDict, List, Optional
 
 from datamodel_code_generator.imports import Import
 from datamodel_code_generator.model import DataModel, DataModelFieldBase
-from datamodel_code_generator.model.pydantic.types import get_data_type
-from datamodel_code_generator.types import DataType, Types
 
 
 class DataClass(DataModel):
@@ -21,6 +19,7 @@ class DataClass(DataModel):
         extra_template_data: Optional[DefaultDict[str, Any]] = None,
         auto_import: bool = True,
         reference_classes: Optional[List[str]] = None,
+        path: Optional[Path] = None,
     ):
 
         super().__init__(
@@ -33,9 +32,6 @@ class DataClass(DataModel):
             extra_template_data=extra_template_data,
             auto_import=auto_import,
             reference_classes=reference_classes,
+            path=path,
         )
         self.imports.append(Import.from_full_path('pydantic.dataclasses.dataclass'))
-
-    @classmethod
-    def get_data_type(cls, types: Types, **kwargs: Any) -> DataType:
-        return get_data_type(types, **kwargs)
