@@ -199,6 +199,7 @@ class JsonSchemaParser(Parser):
         force_optional_for_required_fields: bool = False,
         class_name: Optional[str] = None,
         use_standard_collections: bool = False,
+        base_path: Optional[Path] = None,
     ):
         super().__init__(
             source=source,
@@ -221,6 +222,7 @@ class JsonSchemaParser(Parser):
             force_optional_for_required_fields=force_optional_for_required_fields,
             class_name=class_name,
             use_standard_collections=use_standard_collections,
+            base_path=base_path,
         )
 
         self.remote_object_cache: Dict[str, Dict[str, Any]] = {}
@@ -589,6 +591,7 @@ class JsonSchemaParser(Parser):
             custom_base_class=self.base_class,
             custom_template_dir=self.custom_template_dir,
             extra_template_data=self.extra_template_data,
+            path=self.current_source_path,
         )
 
         self.append_result(data_model_root)
@@ -656,7 +659,7 @@ class JsonSchemaParser(Parser):
                     field_name = f'{obj.type}_{enum_part}'
             enum_fields.append(
                 self.data_model_field_type(
-                    name=field_name,
+                    name=self.model_resolver.get_valid_name(field_name),
                     default=default,
                     data_type=self.data_type_manager.get_data_type(Types.any),
                     required=True,
